#HOW TO USE(SYNTAX):
import SaduStatistics as SS
from SaduStatistics import CentralTendency
from SaduStatistics import VarianceMeasures
from SaduStatistics import InferentialStatistics


#SECOND INSTALL REQUIREMENTS(LIBRARIES):
1. matplotlib
2. math
3. scipy
4. sklearn
5. numpy


